#include "oulib.h"

/*!
   Read the analog-to-digital converter.  This function blocks (waits) until
   a value is available to be read from the ADC.

   <P>
   Assumptions: a conversion is ongoing or has completed, and adlar = ADC_ADLAR_RIGHT
   <P>
   @return The value read from the analog-to-digital converter (0 ... 0x3ff)

   @author Andrew H. Fagg

   \ingroup adc
*/

uint16_t adc_read(void)
{
  uint16_t out;
  uint8_t sreg;

  // Disable global interrupts if they are enabled
  sreg = SREG;
  cli();

  // Wait for ADC data to be ready
  while(!adc_interrupt_flag()){};

  // Read out the value: order of register access is important!
  out = (uint16_t) ADCL;
  out |= (((uint16_t) (ADCH&0x3)) << 8);

  // Restore global interrupt state
  SREG = sreg;

  return(out);
};
