#include "oulib.h"

/**
   Select the ADC channel for the <B>next</B> conversion.  If a
   conversion is already ongoing, this change will not affect it.
   
   <P>

   @param chan A channel number.  Acceptable values are 0 .. 15, however
   useful values will vary between specific chips.  For the mega8, viable
   values are: <BR> ADC_CHANNEL_0 (default),  ... ADC_CHANNEL_7, ADC_CHANNEL_1p23V (1.23V reference), and ADC_CHANNEL_0V (0V reference)

   @author Andrew H. Fagg

   \ingroup adc
*/


//  Channel selection
void adc_set_channel(uint8_t chan)
{
#ifdef ADC_CHANS_16
  // Have 5 bits to specify the input configuration
  ADMUX = (ADMUX & 0xE0) | ((chan & 0x1F));
  ADCSRB = (ADCSRB & ~(1<<MUX5)) | (((chan & 0x20)>>5)<<MUX5);
#else
  ADMUX = (ADMUX & 0xF0) | ((chan & 0xF));
#endif
}
