#include "buffer.h"

/**
   Create and initialize a circular buffer object.  Allocates the buffer
   object space from the heap.
   <P>

   @param size The number of bytes in the circular buffer.  Note that
   a full buffer has size-1 bytes in it.

   @return A pointer to an existing and initialized BUFFER structure. <BR>
   NULL if an error has occurred
   
   @author Andrew H. Fagg (fagg@cs.ou.edu)

   \ingroup buffer
*/

BUFFER* buffer_create(uint16_t size)
{
  BUFFER* buf;

  // Allocate space for object
  if((buf = malloc(sizeof(BUFFER))) == 0)
    return(NULL);

  // Allocate space for the buffer itself
  if(size == 0 || (buf->buffer = malloc(size)) == 0){
    free(buf);
    return(NULL);
  };

  // Initialize other variables
  buf->size = size;
  buf->front = buf->back = 0;
  
  return(buf);
};

