#include "oulib.h"

#if 0
// convert from loop cycles to msecs
#define _delay_ms(x) _delay_loop_2((x)*(F_CPU/4000))

/*
  void delay_ms(unsigned int t)

  _delay_loop_2() can only take a 16-bit argument.  This routine
    repeatedly calls _delay_loop_2() in order to get the desired busy
    wait length.  Note that there is some overhead in the loop that is
    not counted in the delay (so the delay is actually just a little longer)

*/

void delay_ms(unsigned int t) {
  unsigned int nloops = (unsigned short) (t >> MS_SHIFT);
  unsigned int i;

  for(i = 0; i < nloops; ++i) {
    _delay_ms(256UI);
  };
  i = t & MS_GATE;
  if(i > 0) {
    _delay_ms(i);
  };

};

#endif

/**
   Delay for the specified number of milliseconds.

   <P>

   Implemented using busy-waiting, so time spent in ISRs
   does not count.  This is also only an approximate delay.

   <P>

   Note: must be compiled with F_CPU set for the target system
   clock configuration.  We assume that F_CPU is divisible by 4000

   <P>
   @param t Number of milliseconds to delay.

   @author Andrew H. Fagg

   \ingroup delay
*/

void delay_ms(unsigned int t) {
  uint32_t ncycles = t * (F_CPU/4000);
  uint32_t nloops = (uint16_t) (ncycles >> 16); 
  uint32_t i;

  for(i = 0; i < nloops; ++i) {
    _delay_loop_2(0UL);
  };
  i = ncycles & 0xFFFF;
  if(i > 0) {
    _delay_loop_2((uint16_t) i);
  };

};
