#include "oulib.h"

/////////////////////////////////////////////////////////////////////
/*
  void delay_us(unsigned int t)

  Busy wait for a specified number of microseconds.

  Assumptions:
  - F_CPU is a multiple of 1,000,000

  Note:
  - Maximum delay will vary with F_CPU

  For a 1MHz clock:
  - You can delay up to 65535 us
  - Your resolution is 4 us

  For a 16MHz clock:
  - Delay up to 4095 us
  - Resolution is 1 us

*/

/**
 */


/**
   Delay for the specified number of microseconds.

   <P>

   Implemented using busy-waiting, so time spent in ISRs
   does not count.  This is also only an approximate delay.

   <P>

   Note: must be compiled with F_CPU set for the target system
   clock configuration.  We assume that F_CPU is divisible by 1,000,000

   <P>
   @param t Number of microseconds to delay.  <BR>
   For 1MHz clock: delay up to 65535 us, with a resolution of 4 us <BR>
   For 16MHz clock: delay up to 4095 us, with a resolution of 1 us

   @author Andrew H. Fagg

   \ingroup delay
*/

inline void delay_us(unsigned int t) {
  _delay_loop_2((t*(F_CPU/1000000UL)) >> 2);
};
