#include "oulib.h"

//////////////////////////////////////////////////////////////////////
// Serial interface support

//  I/O interface (enables things like getchar(), putchar(), printf(),
// scanf() to work



/**
   LibC interface function for sending a character to the output buffer.  This
   function should <B>never</B> be called by user code.

   @param c Character to send
   @param fp A valid file pointer for the desired output port

   @return 0 if no errors

   @author Andrew H. Fagg

   \ingroup serial_support
 */

int uart_send_general_buffered(char c, FILE *fp)  
{
  struct OU_FILE_BUF *ou_fp =  (struct OU_FILE_BUF *) fdev_get_udata(fp);

  //#ifndef OULIB_EXP
  //  switch(ou_fp->port)
  //{
  //case 0:
  //  loop_until_bit_is_set(UCSRA, UDRE);
  //  UDR = c;
  //  break;
  //#ifdef SERIAL_NPORTS_2
    //case 1:
  //      loop_until_bit_is_set(UCSR1A, UDRE1);
  //  UDR1 = c;
  //  break;
  //};     
  //#endif
  //#else
  if(ou_fp->buf_size_out > 1)  {
    // Using the buffer

    // Wait until there is space available in the buffer
    while((ou_fp->buf_size_out + ou_fp->buf_out_back - ou_fp->buf_out_front)%ou_fp->buf_size_out == (ou_fp->buf_size_out - 1)){};
    
    // Add the element to the buffer
    ou_fp->buffer[ou_fp->buf_size_in + ou_fp->buf_out_back] = c;

    // Increment the index
    ou_fp->buf_out_back = (ou_fp->buf_out_back+1)%ou_fp->buf_size_out;

    // Enable the interrupt
#if defined(SERIAL_NPORTS_2) | defined(SERIAL_NPORTS_4)
    switch(ou_fp->port)
      {
      case 0:
	serial0_transmit_enable();
	break;
      case 1:
	serial1_transmit_enable();
	break;
#if defined(SERIAL_NPORTS_4)
      case 2:
	serial2_transmit_enable();
	break;
      case 3:
	serial3_transmit_enable();
	break;
#endif
      };
#else
    serial0_transmit_enable();
#endif
  }else{
    // Not using the buffer
    switch(ou_fp->port)
      {
      case 0:
	loop_until_bit_is_set(UCSRA, UDRE);
	UDR = c;
	break;
#if defined(SERIAL_NPORTS_2) | defined(SERIAL_NPORTS_4)
      case 1:
	loop_until_bit_is_set(UCSR1A, UDRE1);
	UDR1 = c;
	break;
#endif
#if defined(SERIAL_NPORTS_4)
      case 2:
	loop_until_bit_is_set(UCSR2A, UDRE2);
	UDR2 = c;
	break;
      case 3:
	loop_until_bit_is_set(UCSR3A, UDRE3);
	UDR3 = c;
	break;
#endif

      };     
  };
  //#endif

  return 0;

}



//  int uart_recv(void)
//
//  Receive a byte from the serial port
//
//  Deal with the multi-port case.
//

/**
   LibC interface function for receiving a character from the input buffer.  This
   function should <B>never</B> be called by user code.

   @param fp A valid file pointer for the desired output port

   @return The next character in the buffer.  

   @author Andrew H. Fagg

   \ingroup serial_support
 */
int uart_recv_general_buffered(FILE *fp)  // p.140
{
  struct OU_FILE_BUF *ou_fp =  (struct OU_FILE_BUF *) fdev_get_udata(fp);

  // Wait until there is something in the buffer
  while(ou_fp->buf_in_front == ou_fp->buf_in_back){
    //PORTB ^=3;
    //delay_ms(100);
  };

  // Get the next byte
  int out = ou_fp->buffer[ou_fp->buf_in_front];

  // Increment front
  ou_fp->buf_in_front = (ou_fp->buf_in_front+1)%ou_fp->buf_size_in;
  return(out);
}



/**
   Interrupt service routine body for receiving a byte on a serial port.  This
   function should <B>never</B> be called by user code.

   <P>

   Bytes not fitting in the buffer are dropped on the floor
   
   @param ou_fp A valid OU File structure for the input port

   @author Andrew H. Fagg

   \ingroup serial_support
 */

void serial_receive_isr(struct OU_FILE_BUF *ou_fp)
{
  char c;

  // Get the byte
  switch(ou_fp->port)
    {
    case 0:
      if(bit_is_clear(UCSRA, RXC)) {
	// This case should not happen, but it protects us in case
	//  there is not something in the hardware buffer
	return;
      };
      c = UDR;
      break;
#if defined(SERIAL_NPORTS_2) | defined(SERIAL_NPORTS_4)
    case 1:
      if(bit_is_clear(UCSR1A, RXC1)) {
	// This case should not happen, but it protects us in case
	//  there is not something in the hardware buffer
	return;
      };
      c = UDR1;
      break;
#endif
#ifdef SERIAL_NPORTS_4
    case 2:
      if(bit_is_clear(UCSR2A, RXC2)) {
	// This case should not happen, but it protects us in case
	//  there is not something in the hardware buffer
	return;
      };
      c = UDR2;
      break;
    case 3:
      if(bit_is_clear(UCSR3A, RXC3)) {
	// This case should not happen, but it protects us in case
	//  there is not something in the hardware buffer
	return;
      };
      c = UDR3;
      break;
#endif
    };

  // Now attempt to insert character into the buffer
  if((ou_fp->buf_size_in + ou_fp->buf_in_back - ou_fp->buf_in_front)%ou_fp->buf_size_in <
     (ou_fp->buf_size_in-1)) {
    // There is room in the buffer

    // Store the byte
    ou_fp->buffer[ou_fp->buf_in_back] = c;
    
    // Increment the pointer
    ou_fp->buf_in_back = (ou_fp->buf_in_back+1)%ou_fp->buf_size_in;
    
  };
};


//#ifdef OULIB_EXP


/**
   Interrupt service routine body for sending a byte to a serial port.  This
   function should <B>never</B> be called by user code.

   <P>

   @param ou_fp A valid OU File structure for the output port

   @author Andrew H. Fagg

   \ingroup serial_support
 */

void serial_transmit_isr(struct OU_FILE_BUF *ou_fp)
{
  // Is there actually something in the buffer to send?
  if(ou_fp->buf_out_front == ou_fp->buf_out_back) {
    // No: turn off this isr
    switch(ou_fp->port)
      {
      case 0:
	serial0_transmit_disable();
	break;
#if defined(SERIAL_NPORTS_2) | defined(SERIAL_NPORTS_4)
      case 1:
	serial1_transmit_disable();
	break;

#endif
#if defined(SERIAL_NPORTS_4)
      case 2:
	serial2_transmit_disable();
	break;
      case 3:
	serial3_transmit_disable();
	break;

#endif
    }
    return;
  };

  // Pull the character out of the buffer
  char c = ou_fp->buffer[ou_fp->buf_out_front+ou_fp->buf_size_in];

  // Increment the front pointer
  ou_fp->buf_out_front = (ou_fp->buf_out_front+1)%ou_fp->buf_size_out;

  // Push the character into the hardware buffer
  switch(ou_fp->port)
    {
    case 0:
      UDR = c;
      break;
#if defined(SERIAL_NPORTS_2) | defined(SERIAL_NPORTS_4)
    case 1:
      UDR1 = c;
      break;
#endif      
#if defined(SERIAL_NPORTS_4)
    case 2:
      UDR2 = c;
      break;
    case 3:
      UDR3 = c;
      break;
#endif      
    };
};

//#endif
