#include "oulib.h"

/**
   Determine the clock source for timer 0

   @param config One of: <BR> TIMER0_NOCLK: no input clock <BR>
   TIMER0_NOPRE: No prescalar <BR>
   TIMER0_PRE_8: Prescalar of 8 <BR>
   TIMER0_PRE_64: Prescalar of 64 <BR>
   TIMER0_PRE_256: Prescalar of 256 <BR>
   TIMER0_PRE_1024: Prescalar of 1024 <BR>
   TIMER0_EXT_FALLING: Count on falling edge of external pin T0 <BR>
   TIMER0_EXT_RISING: Count on rising edge of external pin T0 <BR>

   @author Andrew H. Fagg

   \ingroup timer0
*/

void timer0_config(uint8_t config) {
  // Replace the lowest 3 bits
#if defined(atmega8) || defined(atmega644p) || defined(at90usb1287)
  TCCR0 = (TCCR0 & 0xF8) | (config & 0x7);
#else
#if defined(atmega168) || defined(atmega2560)

  TCCR0B = (TCCR0B & 0xF8) | (config & 0x7);
#else
  #error "Incomplete implementation"
#endif
#endif

};


