#include "oulib.h"

/**
   Configure the timer 1 output compare unit.

   @param config One of: <BR>
   TIMER1_OUTPUT_COMPARE_CONFIG_NORMAL:  Normal operation <BR>
   TIMER1_OUTPUT_COMPARE_CONFIG_PWM_PC_08: PWM, Phase Correct, 8-bit <BR>
   TIMER1_OUTPUT_COMPARE_CONFIG_PWM_PC_09: PWM, Phase Correct, 9-bit <BR>
   TIMER1_OUTPUT_COMPARE_CONFIG_PWM_PC_10: PWM, Phase Correct, 10-bit <BR>
   TIMER1_OUTPUT_COMPARE_CONFIG_CTC_OCR1A: CTC, Top = OCRA1 <BR>
   TIMER1_OUTPUT_COMPARE_CONFIG_PWM_F_08: Fast PWM, 8-bit <BR> 
   TIMER1_OUTPUT_COMPARE_CONFIG_PWM_F_09: Fast PWM, 9-bit <BR> 
   TIMER1_OUTPUT_COMPARE_CONFIG_PWM_F_10: Fast PWM, 10-bit <BR> 
   TIMER1_OUTPUT_COMPARE_CONFIG_PWM_PFC_ICR1: PWM, Phase and Frequency Correct, Top = ICR1 <BR>
   TIMER1_OUTPUT_COMPARE_CONFIG_PWM_PFC_OCR1A: PWM, Phase and Frequency Correct, Top = OCR1A <BR>
   TIMER1_OUTPUT_COMPARE_CONFIG_PWM_PC_ICR1: PWM, Phase Correct, Top = ICR1 <BR>
   TIMER1_OUTPUT_COMPARE_CONFIG_PWM_PC_OCR1A: PWM, Phase Correct, Top = OCR1A <BR>
   TIMER1_OUTPUT_COMPARE_CONFIG_CTC_ICR1: CTC, Top = ICR1 <BR>
   TIMER1_OUTPUT_COMPARE_CONFIG_PWM_F_ICR1: Fast PWM, Top = ICR1 <BR>
   TIMER1_OUTPUT_COMPARE_CONFIG_PWM_F_OCR1A: Fast PWM, Top = OCR1A

   @author Andrew H. Fagg

   \ingroup timer1

*/

void timer1_output_compare_config(uint8_t config)
{
  TCCR1A = (TCCR1A & ~(_BV(WGM11) | _BV(WGM10)))
    | ((config&0x3)<<WGM10);
  TCCR1B = (TCCR1B & ~(_BV(WGM13) | _BV(WGM12)))
    | ((config&0xc)<<(WGM12-2));
}




