#include "oulib.h"

#ifdef TIMER3
/**
   Read the state of the timer 3 output compare unit C register.
   <P>
   Note: this implementation is thread safe.

   @return The current state of the timer 3 output compare unit C register.

   @author Andrew H. Fagg

   Only available for the following processors: $(TIMER3_DEVICES)

   \ingroup timer3
*/

uint16_t timer3_output_compare_C_read(void)
{
  uint16_t tmp;
  uint8_t sreg;

  // Disable global interrupts if they are enabled
  sreg = SREG;
  cli();

  // Read value from double-byte buffer
  tmp =  (uint16_t) OCR3CL;
  tmp |= (uint16_t) (OCR3CH<<8);

  // Restore global interrupt state
  SREG = sreg;

  return(tmp);
};
#endif





