#include "oulib.h"

#ifdef TIMER3
/**
   Configure the timer 3 output compare unit.

   @param config One of: <BR>
   TIMER3_OUTPUT_COMPARE_CONFIG_NORMAL:  Normal operation <BR>
   TIMER3_OUTPUT_COMPARE_CONFIG_PWM_PC_08: PWM, Phase Correct, 8-bit <BR>
   TIMER3_OUTPUT_COMPARE_CONFIG_PWM_PC_09: PWM, Phase Correct, 9-bit <BR>
   TIMER3_OUTPUT_COMPARE_CONFIG_PWM_PC_10: PWM, Phase Correct, 10-bit <BR>
   TIMER3_OUTPUT_COMPARE_CONFIG_CTC_OCR3A: CTC, Top = OCRA3 <BR>
   TIMER3_OUTPUT_COMPARE_CONFIG_PWM_F_08: Fast PWM, 8-bit <BR> 
   TIMER3_OUTPUT_COMPARE_CONFIG_PWM_F_09: Fast PWM, 9-bit <BR> 
   TIMER3_OUTPUT_COMPARE_CONFIG_PWM_F_10: Fast PWM, 10-bit <BR> 
   TIMER3_OUTPUT_COMPARE_CONFIG_PWM_PFC_ICR3: PWM, Phase and Frequency Correct, Top = ICR3 <BR>
   TIMER3_OUTPUT_COMPARE_CONFIG_PWM_PFC_OCR3A: PWM, Phase and Frequency Correct, Top = OCR3A <BR>
   TIMER3_OUTPUT_COMPARE_CONFIG_PWM_PC_ICR3: PWM, Phase Correct, Top = ICR3 <BR>
   TIMER3_OUTPUT_COMPARE_CONFIG_PWM_PC_OCR3A: PWM, Phase Correct, Top = OCR3A <BR>
   TIMER3_OUTPUT_COMPARE_CONFIG_CTC_ICR3: CTC, Top = ICR3 <BR>
   TIMER3_OUTPUT_COMPARE_CONFIG_PWM_F_ICR3: Fast PWM, Top = ICR3 <BR>
   TIMER3_OUTPUT_COMPARE_CONFIG_PWM_F_OCR3A: Fast PWM, Top = OCR3A

   @author Andrew H. Fagg

   Only available for the following processors: $(TIMER3_DEVICES)

   \ingroup timer3

*/

void timer3_output_compare_config(uint8_t config)
{
  TCCR3A = (TCCR3A & ~(_BV(WGM31) | _BV(WGM30)))
    | ((config&0x3)<<WGM30);
  TCCR3B = (TCCR3B & ~(_BV(WGM33) | _BV(WGM32)))
    | ((config&0xc)<<(WGM32-2));
}
#endif




