#include "oulib.h"

#ifdef TIMER3
/**
   Read the state of the timer 3 counter.
   <P>
   Note: this implementation is thread safe.

   @return The current state of the timer 3 counter

   @author Andrew H. Fagg

   Only available for the following processors: $(TIMER3_DEVICES)

   \ingroup timer3
*/
uint16_t timer3_read(void) {
  uint16_t tmp;
  uint8_t sreg;

  // Disable global interrupts if they are enabled
  sreg = SREG;
  cli();

  // Access register: order matters!
  tmp = (uint16_t) TCNT3L;
  tmp |= (uint16_t) (TCNT3H<<8);

  // Restore global interrupt state
  SREG = sreg;
  return(tmp);
};

#endif

