#include "oulib.h"

#ifdef TIMER4
/**
   Configure the timer 4 output compare unit.

   @param config One of: <BR>
   TIMER4_OUTPUT_COMPARE_CONFIG_NORMAL:  Normal operation <BR>
   TIMER4_OUTPUT_COMPARE_CONFIG_PWM_PC_08: PWM, Phase Correct, 8-bit <BR>
   TIMER4_OUTPUT_COMPARE_CONFIG_PWM_PC_09: PWM, Phase Correct, 9-bit <BR>
   TIMER4_OUTPUT_COMPARE_CONFIG_PWM_PC_10: PWM, Phase Correct, 10-bit <BR>
   TIMER4_OUTPUT_COMPARE_CONFIG_CTC_OCR4A: CTC, Top = OCRA4 <BR>
   TIMER4_OUTPUT_COMPARE_CONFIG_PWM_F_08: Fast PWM, 8-bit <BR> 
   TIMER4_OUTPUT_COMPARE_CONFIG_PWM_F_09: Fast PWM, 9-bit <BR> 
   TIMER4_OUTPUT_COMPARE_CONFIG_PWM_F_10: Fast PWM, 10-bit <BR> 
   TIMER4_OUTPUT_COMPARE_CONFIG_PWM_PFC_ICR4: PWM, Phase and Frequency Correct, Top = ICR4 <BR>
   TIMER4_OUTPUT_COMPARE_CONFIG_PWM_PFC_OCR4A: PWM, Phase and Frequency Correct, Top = OCR4A <BR>
   TIMER4_OUTPUT_COMPARE_CONFIG_PWM_PC_ICR4: PWM, Phase Correct, Top = ICR4 <BR>
   TIMER4_OUTPUT_COMPARE_CONFIG_PWM_PC_OCR4A: PWM, Phase Correct, Top = OCR4A <BR>
   TIMER4_OUTPUT_COMPARE_CONFIG_CTC_ICR4: CTC, Top = ICR4 <BR>
   TIMER4_OUTPUT_COMPARE_CONFIG_PWM_F_ICR4: Fast PWM, Top = ICR4 <BR>
   TIMER4_OUTPUT_COMPARE_CONFIG_PWM_F_OCR4A: Fast PWM, Top = OCR4A

   @author Andrew H. Fagg

   Only available for the following processors: $(TIMER4_DEVICES)

   \ingroup timer4

*/

void timer4_output_compare_config(uint8_t config)
{
  TCCR4A = (TCCR4A & ~(_BV(WGM41) | _BV(WGM40)))
    | ((config&0x3)<<WGM40);
  TCCR4B = (TCCR4B & ~(_BV(WGM43) | _BV(WGM42)))
    | ((config&0xc)<<(WGM42-2));
}
#endif




