#include "oulib.h"

#ifdef TIMER4
/**
   Read the state of the timer 4 counter.
   <P>
   Note: this implementation is thread safe.

   @return The current state of the timer 4 counter

   @author Andrew H. Fagg

   Only available for the following processors: $(TIMER4_DEVICES)

   \ingroup timer4
*/
uint16_t timer4_read(void) {
  uint16_t tmp;
  uint8_t sreg;

  // Disable global interrupts if they are enabled
  sreg = SREG;
  cli();

  // Access register: order matters!
  tmp = (uint16_t) TCNT4L;
  tmp |= (uint16_t) (TCNT4H<<8);

  // Restore global interrupt state
  SREG = sreg;
  return(tmp);
};

#endif

