#include "oulib.h"

#ifdef TIMER5
/**
   Configure the timer 5 output compare unit.

   @param config One of: <BR>
   TIMER5_OUTPUT_COMPARE_CONFIG_NORMAL:  Normal operation <BR>
   TIMER5_OUTPUT_COMPARE_CONFIG_PWM_PC_08: PWM, Phase Correct, 8-bit <BR>
   TIMER5_OUTPUT_COMPARE_CONFIG_PWM_PC_09: PWM, Phase Correct, 9-bit <BR>
   TIMER5_OUTPUT_COMPARE_CONFIG_PWM_PC_10: PWM, Phase Correct, 10-bit <BR>
   TIMER5_OUTPUT_COMPARE_CONFIG_CTC_OCR5A: CTC, Top = OCRA5 <BR>
   TIMER5_OUTPUT_COMPARE_CONFIG_PWM_F_08: Fast PWM, 8-bit <BR> 
   TIMER5_OUTPUT_COMPARE_CONFIG_PWM_F_09: Fast PWM, 9-bit <BR> 
   TIMER5_OUTPUT_COMPARE_CONFIG_PWM_F_10: Fast PWM, 10-bit <BR> 
   TIMER5_OUTPUT_COMPARE_CONFIG_PWM_PFC_ICR5: PWM, Phase and Frequency Correct, Top = ICR5 <BR>
   TIMER5_OUTPUT_COMPARE_CONFIG_PWM_PFC_OCR5A: PWM, Phase and Frequency Correct, Top = OCR5A <BR>
   TIMER5_OUTPUT_COMPARE_CONFIG_PWM_PC_ICR5: PWM, Phase Correct, Top = ICR5 <BR>
   TIMER5_OUTPUT_COMPARE_CONFIG_PWM_PC_OCR5A: PWM, Phase Correct, Top = OCR5A <BR>
   TIMER5_OUTPUT_COMPARE_CONFIG_CTC_ICR5: CTC, Top = ICR5 <BR>
   TIMER5_OUTPUT_COMPARE_CONFIG_PWM_F_ICR5: Fast PWM, Top = ICR5 <BR>
   TIMER5_OUTPUT_COMPARE_CONFIG_PWM_F_OCR5A: Fast PWM, Top = OCR5A

   @author Andrew H. Fagg

   Only available for the following processors: $(TIMER5_DEVICES)

   \ingroup timer5

*/

void timer5_output_compare_config(uint8_t config)
{
  TCCR5A = (TCCR5A & ~(_BV(WGM51) | _BV(WGM50)))
    | ((config&0x3)<<WGM50);
  TCCR5B = (TCCR5B & ~(_BV(WGM53) | _BV(WGM52)))
    | ((config&0xc)<<(WGM52-2));
}
#endif




