#include "oulib.h"

#ifdef TIMER5
/**
   Read the state of the timer 5 counter.
   <P>
   Note: this implementation is thread safe.

   @return The current state of the timer 5 counter

   @author Andrew H. Fagg

   Only available for the following processors: $(TIMER5_DEVICES)

   \ingroup timer5
*/
uint16_t timer5_read(void) {
  uint16_t tmp;
  uint8_t sreg;

  // Disable global interrupts if they are enabled
  sreg = SREG;
  cli();

  // Access register: order matters!
  tmp = (uint16_t) TCNT5L;
  tmp |= (uint16_t) (TCNT5H<<8);

  // Restore global interrupt state
  SREG = sreg;
  return(tmp);
};

#endif

