#include "oulib.h"

/**
   Determine the prescaler for the watch dog timer.

   @param pre One of: <BR> WDT_PRE_2K <BR>
   WDT_PRE_4K <BR>
   WDT_PRE_8K <BR>
   WDT_PRE_16K <BR>
   WDT_PRE_32K <BR>
   WDT_PRE_64K <BR>
   WDT_PRE_128K <BR>
   WDT_PRE_256K <BR>
   WDT_PRE_512K <BR>
   WDT_PRE_1024K <BR>
   WDT_PRE_2048K <BR>

   Note: not all options are available for all processors

   @author Andrew H. Fagg

   \ingroup wdt
*/

#ifdef HAS_WDT
void wdt_set_prescaler(WDT_PRESCALE pre) {
#ifdef HAS_WDT_V1
  // Replace the lowest 3 bits
  WDTCR = (WDTCR & ~(_BV(WDP2) | _BV(WDP1) | _BV(WDP0)))
    | (pre & 0x7);
#endif
#ifdef HAS_WDT_V2  
  // Replace the lowest 4 bits
  WDTCSR = (WDTCSR & ~(_BV(WDP3) | _BV(WDP2) | _BV(WDP1) | _BV(WDP0)))
    | ((pre & 0x7)<<WDP0)
    | ((pre & 0x8)<<(WDP3-WDP2-1));
#endif
};
#endif
